aboutsummaryrefslogtreecommitdiff
path: root/internal
diff options
context:
space:
mode:
authorKegsay <kegan@matrix.org>2020-06-04 16:26:35 +0100
committerGitHub <noreply@github.com>2020-06-04 16:26:35 +0100
commit2bd12f635cef281ab0d497c9e1bafe92247d88d5 (patch)
tree3d99154f8505915890bb6233591a77e2d8b5213b /internal
parent9834ac97db042b0c78fbd72652aa534129ca3afe (diff)
Convert serverkeys to inthttp (#1097)
Diffstat (limited to 'internal')
-rw-r--r--internal/basecomponent/base.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/internal/basecomponent/base.go b/internal/basecomponent/base.go
index cd297b82..620b12d6 100644
--- a/internal/basecomponent/base.go
+++ b/internal/basecomponent/base.go
@@ -45,6 +45,7 @@ import (
roomserverAPI "github.com/matrix-org/dendrite/roomserver/api"
rsinthttp "github.com/matrix-org/dendrite/roomserver/inthttp"
serverKeyAPI "github.com/matrix-org/dendrite/serverkeyapi/api"
+ skinthttp "github.com/matrix-org/dendrite/serverkeyapi/inthttp"
"github.com/sirupsen/logrus"
_ "net/http/pprof"
@@ -176,10 +177,9 @@ func (b *BaseDendrite) FederationSenderHTTPClient() federationSenderAPI.Federati
return f
}
-// CreateHTTPServerKeyAPIs returns ServerKeyInternalAPI for hitting the server key
-// API over HTTP
-func (b *BaseDendrite) CreateHTTPServerKeyAPIs() serverKeyAPI.ServerKeyInternalAPI {
- f, err := serverKeyAPI.NewServerKeyInternalAPIHTTP(
+// ServerKeyAPIClient returns ServerKeyInternalAPI for hitting the server key API over HTTP
+func (b *BaseDendrite) ServerKeyAPIClient() serverKeyAPI.ServerKeyInternalAPI {
+ f, err := skinthttp.NewServerKeyClient(
b.Cfg.ServerKeyAPIURL(),
b.httpClient,
b.ImmutableCache,